"""
``django-discover`` provides ``DiscoverItem`` model, that allow displaying an introduction
to an existent or a new feature to the user.
"""

__author__ = 'Clément "clemfromspace" Denoix'
__contact__ = 'clement.denoix@magency.fr'
__homepage__ = 'https://github.com/magencydigital/'
__license__ = 'BSD'
__version__ = '0.0.1a3'
VERSION = tuple(__version__.split('.'))

