# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2018-01-19 02:37
from __future__ import unicode_literals

import django.contrib.postgres.fields.ranges
from django.db import migrations, models
import django_discover.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='DiscoverItem',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('language', django_discover.fields.LanguageField(choices=[('bg', 'Bulgarian'), ('cs', 'Czech'), ('da', 'Dansk'), ('de', 'Deutsch'), ('de-AT', 'Deutsch (Austria)'), ('de-CH', 'Deutsch (Swiss)'), ('nl-BE', 'Dutch (Belgium)'), ('en', 'English'), ('en-GB', 'English (Britain)'), ('es', 'Español'), ('fr', 'Français'), ('fr-BE', 'Français (Belgium)'), ('fr-CH', 'Français (Swiss)'), ('it', 'Italiano'), ('it-CH', 'Italiano (Swiss)'), ('hu', 'Magyar'), ('nl', 'Nederlands'), ('no', 'Norsk'), ('pl', 'Polski'), ('pt', 'Portuguese'), ('sk', 'Slovak'), ('fi', 'Suomi'), ('sv', 'Svenska'), ('el', 'Ελληνικά'), ('ru', 'Русский'), ('ja', '日本語')], help_text='The language of this discover item', max_length=5, verbose_name='Language')),
                ('title', models.CharField(max_length=30, verbose_name='Title')),
                ('slug', models.SlugField(max_length=500, verbose_name='Slug')),
                ('image', models.ImageField(upload_to='django_discover', verbose_name='Image')),
                ('short_description', models.CharField(max_length=50, verbose_name='Short description')),
                ('long_description', models.TextField(verbose_name='Long description')),
                ('link_title', models.CharField(blank=True, max_length=20, null=True, verbose_name='Link title')),
                ('link_url', models.CharField(blank=True, max_length=500, null=True, verbose_name='Link url')),
                ('tag', models.CharField(blank=True, choices=[('new', 'New'), ('important', 'Important')], max_length=20, null=True, verbose_name='Tag')),
                ('category', models.CharField(blank=True, choices=[('resources', 'Resources'), ('sessions', 'Sessions'), ('users', 'Users')], max_length=20, null=True, verbose_name='Category')),
                ('major_versions', django.contrib.postgres.fields.ranges.IntegerRangeField(blank=True, null=True, verbose_name='Major version range')),
                ('minor_versions', django.contrib.postgres.fields.ranges.IntegerRangeField(blank=True, null=True, verbose_name='Minor version range')),
                ('hotfix_versions', django.contrib.postgres.fields.ranges.IntegerRangeField(blank=True, null=True, verbose_name='Hotfix version range')),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Date and time of creation')),
                ('updated_at', models.DateTimeField(auto_now=True, verbose_name='Date and time of the last update')),
            ],
        ),
        migrations.AlterUniqueTogether(
            name='discoveritem',
            unique_together=set([('language', 'slug')]),
        ),
    ]
